summaryrefslogtreecommitdiffstats
path: root/src/build
diff options
context:
space:
mode:
authorCamVan Nguyen <ctnguyen@us.ibm.com>2012-02-03 12:25:27 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2012-02-07 11:57:25 -0600
commitcadd824189729c71542271e41460290ed7c5e961 (patch)
treeed6e2ab9653572f76f5b688e67122612ab501045 /src/build
parent4f09f9f6573e174c72b684b883d77f824fe949fe (diff)
downloadtalos-hostboot-cadd824189729c71542271e41460290ed7c5e961.tar.gz
talos-hostboot-cadd824189729c71542271e41460290ed7c5e961.zip
Changes to VPO tools:
Add tool's directory to perl's search path so tool modules can be found and tool can be invoked from anywhere. Change to use Hostboot's own copies of external vbu tools. Change to use common arguments for tools. Change-Id: Ide6233df381e33e724c4b57bf5fdeb37ff7233bb Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/645 Tested-by: Jenkins Server Reviewed-by: Mark W. Wenning <wenning@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/build')
-rwxr-xr-xsrc/build/debug/Hostboot/Errl.pm2
-rwxr-xr-xsrc/build/debug/hb-dump-debug15
-rwxr-xr-xsrc/build/debug/vpo-debug-framework.pl49
-rwxr-xr-xsrc/build/tools/cpfiles.pl7
-rwxr-xr-xsrc/build/tools/hb-parsedump.pl34
-rwxr-xr-xsrc/build/vpo/hb-dump46
-rwxr-xr-xsrc/build/vpo/hb-virtdebug.pl49
7 files changed, 93 insertions, 109 deletions
diff --git a/src/build/debug/Hostboot/Errl.pm b/src/build/debug/Hostboot/Errl.pm
index 654b10e46..ca4564d24 100755
--- a/src/build/debug/Hostboot/Errl.pm
+++ b/src/build/debug/Hostboot/Errl.pm
@@ -100,7 +100,7 @@ sub main
close( ERRLDATA );
my $imagePath;
- $imagePath = ::determineImagePath();
+ $imagePath = ::getImgPath();
if (not defined $imagePath)
{
::userDisplay "Can not find img path to errlparser binary.\n";
diff --git a/src/build/debug/hb-dump-debug b/src/build/debug/hb-dump-debug
index 600187f61..20b0b2b54 100755
--- a/src/build/debug/hb-dump-debug
+++ b/src/build/debug/hb-dump-debug
@@ -27,18 +27,29 @@ use strict;
use Getopt::Long;
use Pod::Usage;
use IO::Seekable;
+use File::Basename;
+use lib dirname (__FILE__);
use Hostboot::_DebugFramework;
my $tool = "";
my $dumpfile = "";
my $testImage = 0;
-my $imgPath = "";
my $toolOptions = "";
my $cfgHelp = 0;
my $cfgMan = 0;
my $toolHelp = 0;
+my $imgPath = "";
+my $hbDir = $ENV{'HBDIR'};
+if (defined ($hbDir))
+{
+ if ($hbDir ne "")
+ {
+ $imgPath = "$hbDir/";
+ }
+}
+
GetOptions("tool:s" => \$tool,
"tool-options:s" => \$toolOptions,
"file:s" => \$dumpfile,
@@ -169,6 +180,8 @@ Use the hbicore_test.syms file instead of the default.
=item B<--img-path>=PATH
The path to the "img" directory where the syms file, etc is located.
+User can also set the env variable HBDIR to the path of the "img"
+directory instead of using this option.
=item B<--help>
diff --git a/src/build/debug/vpo-debug-framework.pl b/src/build/debug/vpo-debug-framework.pl
index ab96ac7ae..244c834b5 100755
--- a/src/build/debug/vpo-debug-framework.pl
+++ b/src/build/debug/vpo-debug-framework.pl
@@ -33,6 +33,8 @@ use Getopt::Long;
use Pod::Usage;
use File::Temp ('tempfile');
use File::Basename;
+use lib dirname (__FILE__);
+#print __FILE__."\n";
use Hostboot::_DebugFramework;
@@ -47,15 +49,17 @@ use constant NUMTHREADS => 8;
# Common options for the different tools in VPO environment
#------------------------------------------------------------
my %optionInfo = (
- "--test" => "Use the hbicore_test.syms file instead of the default.",
- "--img-path=<path>" => "The path to the \"img\" directory where the syms file, etc is located.",
- "--out-path=<path>" => "The path to the directory where the output will be saved.",
- "--debug" => "Enable debug tracing.",
- "-k#" => "The cage to act on.",
- "-n#" => "The node to act on.",
- "-s#" => "The slot to act on.",
- "-p#" => "The chip position to act on.",
- "-c#" => "The core/chipUnit to act on.",
+ "--test" => ["Use the hbicore_test.syms file instead of the default."],
+ "--img-path=<path>" => ["The path to the \"img\" directory where the syms file, etc is located.",
+ "User can also set the env variable HBDIR to the path of the \"img\"",
+ "directory instead of using this option."],
+ "--out-path=<path>" => ["The path to the directory where the output will be saved."],
+ "--debug" => ["Enable debug tracing."],
+ "-k#" => ["The cage to act on."],
+ "-n#" => ["The node to act on."],
+ "-s#" => ["The slot to act on."],
+ "-p#" => ["The chip position to act on."],
+ "-c#" => ["The core/chipUnit to act on."],
);
#--------------------------------------------------------------------------------
@@ -76,6 +80,7 @@ my @ecmdOpt = ("-c3");
my @threadState = ();
my $l2Flushed = 0;
my $fh;
+my $vbuToolDir = "/gsa/ausgsa/projects/h/hostboot/vbutools/latest";
my $imgPath = "";
my $hbDir = $ENV{'HBDIR'};
@@ -240,8 +245,7 @@ sub flushL2
#stop instructions
stopInstructions("all");
- my $command = "/afs/awd.austin.ibm.com/projects/eclipz/lab/p8/compiled_procs/procs/p8_l2_flush_wrap.x86 ";
- $command .= "@ecmdOpt $flag";
+ my $command = "$vbuToolDir/p8_l2_flush_wrap.x86 @ecmdOpt $flag";
die "ERROR: cannot flush L2" if (system("$command") != 0);
$l2Flushed = 1;
@@ -277,7 +281,7 @@ sub readData
#Read the cache lines from L3 and save to temp file
my (undef, $fname) = tempfile("tmpXXXXX");
- my $command = sprintf ("p8_dump_l3 %x $numCacheLines -f $fname -b @ecmdOpt",
+ my $command = sprintf ("$vbuToolDir/p8_dump_l3 %x $numCacheLines -f $fname -b @ecmdOpt",
$addr);
if ($debug)
@@ -344,8 +348,7 @@ sub writeData
}
#write the cachelines
- my $command = sprintf("/afs/awd/projects/eclipz/lab/p8/gsiexe/p8_load_l3 -f $fname -o 0x%x -b @ecmdOpt",
- $base);
+ my $command = sprintf("$vbuToolDir/p8_load_l3 -f $fname -o 0x%x -b @ecmdOpt", $base);
die "ERROR: cannot write L3" if (system("$command") != 0);
unlink($fname);
@@ -369,10 +372,8 @@ sub stopInstructions
{
my $thread = shift;
- #todo Change to a hostboot dir where a copy of the tool will be kept
#Stopping all threads
- my $command = "/afs/awd/projects/eclipz/lab/p8/u/karm/ekb/eclipz/chips/p8/working/procedures/utils/p8_thread_control.x86";
- $command .= " @ecmdOpt -stop -t$thread $flag";
+ my $command = "$vbuToolDir/p8_thread_control.x86 @ecmdOpt -stop -t$thread $flag";
if ($debug)
{
@@ -387,10 +388,8 @@ sub startInstructions
{
my $thread = shift;
- #todo Change to a hostboot dir where a copy of the tool will be kept
#Starting all threads
- my $command = "/afs/awd/projects/eclipz/lab/p8/u/karm/ekb/eclipz/chips/p8/working/procedures/utils/p8_thread_control.x86";
- $command .= " @ecmdOpt -start -t$thread $flag";
+ my $command = "$vbuToolDir/p8_thread_control.x86 @ecmdOpt -start -t$thread $flag";
if ($debug)
{
@@ -409,9 +408,7 @@ sub queryThreadState
{
my $thread = shift;
- #todo Change to a hostboot dir where a copy of the tool will be kept
- my $command = "/afs/awd/projects/eclipz/lab/p8/u/karm/ekb/eclipz/chips/p8/working/procedures/utils/p8_thread_control.x86";
- $command .= " @ecmdOpt -query -t$thread $flag";
+ my $command = "$vbuToolDir/p8_thread_control.x86 @ecmdOpt -query -t$thread";
my $result = `$command`;
if ($debug)
@@ -591,7 +588,11 @@ sub displayToolModuleHelp
for my $key ( keys %optionInfo )
{
print "\t$key\n";
- print "\t\t$optionInfo{$key}\n";
+
+ for my $i (0 .. $#{ $optionInfo{$key} } )
+ {
+ print "\t\t$optionInfo{$key}[$i]\n";
+ }
}
if (defined $info{notes})
diff --git a/src/build/vpo/hb-dump b/src/build/vpo/hb-dump
index 276fad24e..73e8f07ec 100755
--- a/src/build/vpo/hb-dump
+++ b/src/build/vpo/hb-dump
@@ -34,7 +34,7 @@
#------------------------------------------------------------------------------
use strict;
use warnings;
-
+use File::Basename;
#------------------------------------------------------------------------------
# Forward Declaration
@@ -53,18 +53,8 @@ my $numArgs = $#ARGV + 1;
#print "num args = $numArgs\n";
#print "argument list = @ARGV\n";
-my $hbDir = $ENV{'HBDIR'};
-if (defined ($hbDir))
-{
- unless ($hbDir ne "")
- {
- $hbDir = '.'; #Set to current directory
- }
-}
-else
-{
- $hbDir = '.'; #Set to current directory
-}
+my $toolDir = dirname (__FILE__);
+#print "$toolDir\n";
for (my $i=0; $i<$numArgs; $i++)
{
@@ -74,20 +64,11 @@ for (my $i=0; $i<$numArgs; $i++)
printUsage();
exit (0);
}
- elsif ($ARGV[$i] eq "--in")
- {
- if (($i + 1) >= $numArgs)
- {
- die "No value given for --in parameter.\n";
- }
- $i++;
- $hbDir = $ARGV[$i];
- }
- elsif ($ARGV[$i] eq "--out")
+ elsif ($ARGV[$i] eq "--out-path")
{
if (($i + 1) >= $numArgs)
{
- die "No value given for --out parameter.\n";
+ die "No value given for --out-path parameter.\n";
}
$i++;
}
@@ -103,7 +84,7 @@ for (my $i=0; $i<$numArgs; $i++)
#------------------------------------------------------------------------------
# Dump L3
#------------------------------------------------------------------------------
-my $command = "$hbDir/hb-virtdebug.pl @ARGV";
+my $command = "$toolDir/hb-virtdebug.pl @ARGV";
system($command);
@@ -116,29 +97,20 @@ system($command);
#------------------------------------------------------------------------------
sub printUsage()
{
- print ("\nUsage: hb-dump [--help] | [--in <path to hb-virtdebug.pl>]\n");
- print (" [--out <path to save output data>]\n");
+ print ("\nUsage: hb-dump [--help] |\n");
+ print (" [--out-path <path to save output data>]\n");
print (" [-k#] [-n#] [-s#] [-p#] [-c#]\n\n");
print (" This program dumps the entire L3 to a file.\n");
print (" Use the hb-parsedump.pl program to expand and view data in the file.\n\n");
print (" User should copy hb-virtdebug.pl to the current directory or set\n");
print (" the env variable HBDIR to the path of the file.\n\n");
print (" --help Prints usage information.\n");
- print (" --in Overrides the automatically detected hb-virtdebug.pl file\n");
- print (" in HBDIR or the current directory.\n");
- print (" This program will search for the file in the ");
- print ("following order:\n");
- print (" 1. from the path specified by the user\n");
- print (" 2. from HBDIR if it is defined\n");
- print (" 3. from the current directory\n");
- print (" --out Directory where the output data will be saved.\n");
+ print (" --out-path Directory where the output data will be saved.\n");
print (" Default path is the current directory.\n");
print (" -k# Specify which cage to act on (default = 0).\n");
print (" -n# Specify which node to act on (default = 0).\n");
print (" -s# Specify which slot to act on (default = 0).\n");
print (" -p# Specify which chip position to act on (default = 0).\n");
print (" -c# Specify which core/chipUnit to act on (default = 3).\n");
- print ("\n NOTE: This program will not work if user has not stopped instructions\n");
- print (" prior to running this program.\n");
}
diff --git a/src/build/vpo/hb-virtdebug.pl b/src/build/vpo/hb-virtdebug.pl
index f468c199c..cf2bfe265 100755
--- a/src/build/vpo/hb-virtdebug.pl
+++ b/src/build/vpo/hb-virtdebug.pl
@@ -91,6 +91,7 @@ my $outDir = getcwd(); #Default = current working directory
my @ecmdOpt; #Array of ecmd options
my $core = "3"; #Default is core 3
my @threadState = (); #Array to store the thread states
+my $vbuToolDir = "/gsa/ausgsa/projects/h/hostboot/vbutools/latest";
my $hbDir = $ENV{'HBDIR'};
if (defined ($hbDir))
@@ -113,20 +114,20 @@ for (my $i=0; $i<$numArgs; $i++)
printUsage();
exit (0);
}
- elsif ($ARGV[$i] eq "--in")
+ elsif ($ARGV[$i] eq "--img-path")
{
if (($i + 1) >= $numArgs)
{
- die "No value given for --in parameter.\n";
+ die "No value given for --img-path parameter.\n";
}
$i++;
$hbDir = $ARGV[$i];
}
- elsif ($ARGV[$i] eq "--out")
+ elsif ($ARGV[$i] eq "--out-path")
{
if (($i + 1) >= $numArgs)
{
- die "No value given for --out parameter.\n";
+ die "No value given for --out-path parameter.\n";
}
$i++;
$outDir = $ARGV[$i];
@@ -278,8 +279,7 @@ stopInstructions("all");
#Flush L2 - this step is needed in order to dump L3 quickly
#------------------------------------------------------------------------------
my $command = "";
-$command = "/afs/awd.austin.ibm.com/projects/eclipz/lab/p8/compiled_procs/procs/p8_l2_flush_wrap.x86 ";
-$command .= "@ecmdOpt -quiet";
+$command = "$vbuToolDir/p8_l2_flush_wrap.x86 @ecmdOpt -quiet";
#print "$command\n";
die "ERROR: cannot flush L2" if (system("$command") != 0);
@@ -315,7 +315,7 @@ if ($dumpPrintk)
#print "addr $addr, offset $offset, size $size, cacheLines $cacheLines\n";
#Read the kernel printk buffer from L3 and save to file
- $command = sprintf ("p8_dump_l3 %x $cacheLines -f $string -b @ecmdOpt",
+ $command = sprintf ("$vbuToolDir/p8_dump_l3 %x $cacheLines -f $string -b @ecmdOpt",
$addr);
print "$command\n";
die if (system("$command") != 0);
@@ -365,7 +365,7 @@ if ($dumpTrace)
}
#print "addr $addr, offset $offset, size $size, cacheLines $cacheLines\n";
- $command = sprintf ("p8_dump_l3 %x $cacheLines -f $string -b @ecmdOpt",
+ $command = sprintf ("$vbuToolDir/p8_dump_l3 %x $cacheLines -f $string -b @ecmdOpt",
$addr);
print "$command\n";
die if (system("$command") != 0);
@@ -397,7 +397,7 @@ if ($dumpTrace)
}
#print "$compName, addr $compBufAddr, offset $offset, cacheLines $cacheLines\n";
- $command = sprintf ("p8_dump_l3 %x $cacheLines -f $outDir/trace.out -b @ecmdOpt",
+ $command = sprintf ("$vbuToolDir/p8_dump_l3 %x $cacheLines -f $outDir/trace.out -b @ecmdOpt",
$compBufAddr);
print "$command\n";
die if (system("$command") != 0);
@@ -418,7 +418,7 @@ if ($dumpTrace)
$cacheLines += 1;
}
#print "$compName, addr $compBufAddr, offset $offset, cacheLines $cacheLines\n";
- $command = sprintf ("p8_dump_l3 %x $cacheLines -f $outDir/trace.out -b @ecmdOpt",
+ $command = sprintf ("$vbuToolDir/p8_dump_l3 %x $cacheLines -f $outDir/trace.out -b @ecmdOpt",
$compBufAddr);
print "$command\n";
die if (system("$command") != 0);
@@ -500,7 +500,7 @@ if ($dumpErrl)
}
#print "addr $addr, offset $offset, size $size, cacheLines $cacheLines\n";
- $command = sprintf ("p8_dump_l3 %x $cacheLines -f $string -b @ecmdOpt",
+ $command = sprintf ("$vbuToolDir/p8_dump_l3 %x $cacheLines -f $string -b @ecmdOpt",
$addr);
print "$command\n";
die if (system("$command") != 0);
@@ -531,7 +531,7 @@ if ($dumpErrl)
}
else
{
- print "\nWARNING: Cannot read the error logs.\n";
+ print "\nWARNING: Cannot read the error logs.\n";
}
}
}
@@ -551,7 +551,7 @@ if ($dumpAll)
#Dump L3 to file
my $hbDumpFile = "$outDir/hbdump.$timeStamp";
- $command = "p8_dump_l3 0 65536 -f $hbDumpFile -b @ecmdOpt";
+ $command = "$vbuToolDir/p8_dump_l3 0 65536 -f $hbDumpFile -b @ecmdOpt";
#print "$command\n";
die "ERROR: cannot dump L3" if (system("$command") != 0);
@@ -564,7 +564,7 @@ if ($dumpAll)
else
{
print "\nWARNING: Cannot dump L3. Did you stop instructions?\n\n";
- unlink $hbDumpFile;
+ unlink $hbDumpFile;
}
}
@@ -586,9 +586,8 @@ sub stopInstructions
{
my $thread = shift;
- #todo Change to a hostboot dir where a copy of the tool will be kept
#Stopping all threads
- my $command = "/afs/awd/projects/eclipz/lab/p8/u/karm/ekb/eclipz/chips/p8/working/procedures/utils/p8_thread_control.x86";
+ my $command = "$vbuToolDir/p8_thread_control.x86";
$command .= " @ecmdOpt -stop -t$thread -quiet";
die "ERROR: cannot stop instructions" if (system("$command") != 0);
}
@@ -600,9 +599,8 @@ sub startInstructions
{
my $thread = shift;
- #todo Change to a hostboot dir where a copy of the tool will be kept
#Starting all threads
- my $command = "/afs/awd/projects/eclipz/lab/p8/u/karm/ekb/eclipz/chips/p8/working/procedures/utils/p8_thread_control.x86";
+ my $command = "$vbuToolDir/p8_thread_control.x86";
$command .= " @ecmdOpt -start -t$thread -quiet";
die "ERROR: cannot start instructions" if (system("$command") != 0);
}
@@ -616,14 +614,12 @@ sub queryThreadState
my $thread = shift;
#print "thread $thread\n";
- #todo Change to a hostboot dir where a copy of the tool will be kept
- my $command = "/afs/awd/projects/eclipz/lab/p8/u/karm/ekb/eclipz/chips/p8/working/procedures/utils/p8_thread_control.x86";
- $command .= " @ecmdOpt -query -t$thread --quiet";
+ my $command = "$vbuToolDir/p8_thread_control.x86 @ecmdOpt -query -t$thread";
my $result = `$command`;
#print "result:\n $result";
if ($result =~ m/Quiesced/)
{
- #print "Thread $thread is quiesced\n";
+ #print "Thread $thread is quiesced\n";
return "Quiesced";
}
#print "Thread $thread is running\n";
@@ -777,8 +773,9 @@ sub appendBinFile($$)
#------------------------------------------------------------------------------
sub printUsage()
{
- print ("\nUsage: hb-virtdebug.pl [--help] | [--in <path to .syms file, hbotStringFile & errlparser>]\n");
- print (" [--out <path to save output data>]\n");
+ print ("\nUsage: hb-virtdebug.pl [--help] |\n");
+ print (" [--img-path <path to .syms file, hbotStringFile & errlparser>]\n");
+ print (" [--out-path <path to save output data>]\n");
print (" [--test] [--errl [-l | -d [<logid>|all]] [--printk]\n");
print (" [--trace [<compName1 compName2 compName3 ...>]]\n");
print (" [-k#] [-n#] [-s#] [-p#] [-c#]\n\n");
@@ -790,14 +787,14 @@ sub printUsage()
print (" of the files.\n\n");
print (" User should also set the env variable PATH to include the path to the fsp-trace program.\n\n");
print (" --help Prints usage information\n");
- print (" --in Overrides the automatically detected .syms file,\n");
+ print (" --img-path Overrides the automatically detected .syms file,\n");
print (" hbotStringFile & errlparser in HBDIR or the current\n");
print (" directory. This program will search for the files in\n");
print (" the following order:\n");
print (" 1. from the path specified by user\n");
print (" 2. from HBDIR if it is defined\n");
print (" 3. from the current directory\n");
- print (" --out Directory where the output data will be saved\n");
+ print (" --out-path Directory where the output data will be saved\n");
print (" Default path is the current directory\n");
print (" --test Use the hbicore_test.syms file vs the hbicore.syms file\n");
print (" --errl Dumps the error logs\n");
OpenPOWER on IntegriCloud
diff --git a/src/build/tools/cpfiles.pl b/src/build/tools/cpfiles.pl
index 57ea256c5..a0bd64806 100755
--- a/src/build/tools/cpfiles.pl
+++ b/src/build/tools/cpfiles.pl
@@ -363,16 +363,17 @@ else #release or vpo
push(@files, "printk");
push(@files, "trace");
+ chdir $inDir;
foreach (@files)
{
- # filter out any file prefixed with '_' or '.'
- next if ($_ =~ m/^[._]/);
+ # filter out Example.pm & any file prefixed with '_' or '.'
+ next if ( ($_ =~ m/^[._]/) || ($_ =~ m/Example/) );
my($filename, $directories, $suffix) = fileparse($_, qr{\..*});
# create sym-link
$filename = "hb-$filename";
- $command = "ln -sf $inDir/vpo-debug-framework.pl $inDir/$filename";
+ $command = "ln -sf vpo-debug-framework.pl $filename";
print "$command\n";
die if (system("$command") != 0);
}
diff --git a/src/build/tools/hb-parsedump.pl b/src/build/tools/hb-parsedump.pl
index c190d3a2b..53653878a 100755
--- a/src/build/tools/hb-parsedump.pl
+++ b/src/build/tools/hb-parsedump.pl
@@ -33,8 +33,8 @@
#
# Usage:
# hb-parsedump.pl <dumpfile> [--test]
# [--in <path to .syms file, hbotStringFile, & errlparser>]
# [--out <path to save output data>]\n");
#------------------------------------------------------------------------------
@@ -143,20 +143,20 @@ if (!(-s $hbDumpFile))
# Save the optional user specified arguments
for (my $i=1; $i<$numArgs; $i++)
{
- if ($ARGV[$i] eq "--in")
+ if ($ARGV[$i] eq "--img-path")
{
if (($i + 1) >= $numArgs)
{
- die "No value given for --in parameter.\n";
+ die "No value given for --img-path parameter.\n";
}
$i++;
$hbDir = $ARGV[$i];
}
- elsif ($ARGV[$i] eq "--out")
+ elsif ($ARGV[$i] eq "--out-path")
{
if (($i + 1) >= $numArgs)
{
- die "No value given for --out parameter.\n";
+ die "No value given for --out-path parameter.\n";
}
$i++;
$outDir = $ARGV[$i];
@@ -473,8 +473,8 @@ sub appendBinFile($$)
sub printUsage()
{
print ("\nUsage: hb-parsedump.pl [--help] | <dumpfile> [--test]\n");
- print (" [--in <path to .syms file, hbotStringFile & errlparser>]\n");
- print (" [--out <path to save output data>]\n\n");
+ print (" [--img-path <path to .syms file, hbotStringFile & errlparser>]\n");
+ print (" [--out-path <path to save output data>]\n\n");
print (" This program will parse the hostboot dump file specified\n");
print (" and extract the code version, kernel printk buffer, component\n");
print (" traces & error logs.\n\n");
@@ -483,13 +483,13 @@ sub printUsage()
print (" of the files.\n\n");
print (" User should also set the env variable PATH to include the path to the fsp-trace");
print (" program.\n\n");
- print (" --in: Override the automatically detected .syms file, hbotStringFile\n");
- print (" and errlparser in HBDIR or the current directory.\n");
- print (" This program will search for the files in the following order:\n");
- print (" 1. from the path specified by user\n");
- print (" 2. from HBDIR if it is defined\n");
- print (" 3. from the current directory\n");
- print (" --out: Directory where the output data will be saved.\n");
- print (" Default path is the current directory.\n");
- print (" --test: Use the hbicore_test.syms file vs the hbicore.syms file\n");
+ print (" --img-path: Overrides the automatically detected .syms file, hbotStringFile\n");
+ print (" and errlparser in HBDIR or the current directory.\n");
+ print (" This program will search for the files in the following order:\n");
+ print (" 1. from the path specified by user\n");
+ print (" 2. from HBDIR if it is defined\n");
+ print (" 3. from the current directory\n");
+ print (" --out-path: Directory where the output data will be saved.\n");
+ print (" Default path is the current directory.\n");
+ print (" --test: Use the hbicore_test.syms file vs the hbicore.syms file\n");
}
@@ -33,8 +33,8 @@
# Usage:
# hb-parsedump.pl <dumpfile> [--test]
-# [--in <path to .syms file, hbotStringFile, & errlparser>]
-# [--out <path to save output data>]\n");
+# [--img-path <path to .syms file, hbotStringFile, & errlparser>]
+# [--out-path <path to save output data>]\n");
#------------------------------------------------------------------------------